# Changelog

## [Unreleased]

### Added
- Initial release
- Settings page for API token management
- STDIO and HTTP MCP configuration copy
- Startup notification for first-time setup
- Menu actions under Tools menu
